//
// menger - visualization of the Menger sponge
// Copyright (C) 1995-2020  Joachim Reichel <joachim.reichel@posteo.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//

#ifndef MENGER_GLWIDGET_H
#define MENGER_GLWIDGET_H

#include <string>

#if defined( HAVE_GLEW)
#  include <GL/glew.h>
#endif // HAVE_GLEW

#include <QtWidgets/QOpenGLWidget>

class MainWindow;

class GLWidget : public QOpenGLWidget
{
Q_OBJECT

public:

    GLWidget( MainWindow* mainwindow, QWidget* parent);

    void screenshot( int w, int h, const std::string& filename);

protected:

    void initializeGL() override;
    void paintGL() override;
    void resizeGL( int w, int h) override;

    void mousePressEvent( QMouseEvent* e) override;
    void mouseMoveEvent( QMouseEvent* e) override;
    void mouseReleaseEvent( QMouseEvent* e) override;

    void keyReleaseEvent( QKeyEvent* e) override;

private:

    QPoint m_last;
    QPoint m_last_press;

    Qt::MouseButton m_button_state;

    MainWindow* m_mainwindow;

    int m_low_level;
    int m_level;

    bool m_screenshot_is_active;
    int m_screenshot_width;
    int m_screenshot_height;
    std::string m_screenshot_filename;
};

#endif // MENGER_GLWIDGET_H
