//
// menger - visualization of the Menger sponge
// Copyright (C) 1995-2020  Joachim Reichel <joachim.reichel@posteo.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//

#ifndef MENGER_MAINWINDOW_H
#define MENGER_MAINWINDOW_H

#if defined( HAVE_GLEW)
#  include <GL/glew.h>
#endif // HAVE_GLEW

#include <QtWidgets/QMainWindow>

class Renderer;
class GLWidget;

class MainWindow : public QMainWindow
{
  Q_OBJECT

public:

    static const int max_level = 6;

    MainWindow();

    Renderer* get_renderer() const;
    GLWidget* get_glwidget() const;

public slots:

    void update_menus();

    void level();
    void level( int i);

    void mode();
    void mode( int i);

    void misc_reset();
    void misc_screenshot();
    void misc_fullscreen();
    void misc_use_vbo();
    void misc_about();

    void message( const QString& message) const;
    void message_tmp( const QString& message) const;
    void message_clear() const;

protected:

    virtual void keyPressEvent( QKeyEvent* e);
    virtual void keyReleaseEvent( QKeyEvent* e);

    Renderer* m_renderer;
    GLWidget* m_glwidget;

    QMenu*    m_menu_level;
    QMenu*    m_menu_mode;
    QMenu*    m_menu_misc;

    QAction*  m_action_level[max_level+1];

    QAction*  m_action_mode_fast;
    QAction*  m_action_mode_exact;
    QAction*  m_action_mode_simple;
    QAction*  m_action_mode_stupid;

    QAction*  m_action_misc_reset;
    QAction*  m_action_misc_screenshot;
    QAction*  m_action_misc_fullscreen;
    QAction*  m_action_misc_use_vbo;
    QAction*  m_action_misc_about;
    QAction*  m_action_misc_exit;
};

#endif // MENGER_MAINWINDOW_H
